@@ -41,7 +41,7 @@ in this Software without prior written authorization from The Open Group.
 
 
 /*
- * Based on an optimized version provided by Jim Becker, Auguest 5, 1988.
+ * Based on an optimized version provided by Jim Becker, August 5, 1988.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -59,6 +59,12 @@ in this Software without prior written authorization from The Open Group.
 #include <direct.h>            /* for _getdrives() */
 #endif
 
+#ifdef O_CLOEXEC
+#define FOPEN_CLOEXEC "e"
+#else
+#define FOPEN_CLOEXEC ""
+#endif
+
 #define MAX_SIZE 255
 
 /*
@@ -144,7 +150,7 @@ NextInt(FILE *fstream)
  * The data returned by the following routine is always in left-most byte
  * first and left-most bit first.  If it doesn't return BitmapSuccess then
  * its arguments won't have been touched.  This routine should look as much
- * like the Xlib routine XReadBitmapfile as possible.
+ * like the Xlib routine XReadBitmapFile as possible.
  */
 int
 XmuReadBitmapData(FILE *fstream, unsigned int *width, unsigned int *height,
@@ -226,7 +232,7 @@ XmuReadBitmapData(FILE *fstream, unsigned int *width, unsigned int *height,
 	bytes_per_line = (ww+7)/8 + padding;
 
 	size = bytes_per_line * hh;
-	data = (unsigned char *) Xmalloc ((unsigned int) size);
+	data = Xmalloc ((unsigned int) size);
 	if (!data)
 	  RETURN (BitmapNoMemory);
 
@@ -384,7 +390,7 @@ XmuReadBitmapDataFromFile(_Xconst char *filename, unsigned int *width,
     FILE *fstream;
     int status;
 
-    if ((fstream = fopen_file (filename, "r")) == NULL) {
+    if ((fstream = fopen_file (filename, "r" FOPEN_CLOEXEC)) == NULL) {
 	return BitmapOpenFailed;
     }
     status = XmuReadBitmapData(fstream, width, height, datap, x_hot, y_hot);
